@@ -11,7 +11,7 @@ import numpy as np
 import pandas as pd
 from PIL import Image
 from matplotlib import pyplot as plt
-from shapely.geometry import Polygon
+from shapely.geometry import Polygon, LineString
 import boto3
 
 from .. import constants, queries
@@ -172,6 +172,56 @@ def overlay_origin_and_terminus_points_on_sample_image(
     return save_path
 
 
+def overlay_screen_line_on_sample_image(
+    background_image_path: str,
+    zone_demarcation: Union[List[List[int]], List[List[List[int]]]],
+    save_path: str = "zone-overlaid-image.png",
+    zone_demarcation_boundary_color: Union[str, List[str]] = "green",
+    zone_demarcation_line_width: Union[float, List[float]] = 2.0,
+    zone_demarcation_line_style: Union[str, List[str]] = "solid",
+) -> str:
+    # this function should be similar to overlay_zone_on_sample_image ut uses a LineString instead of a Polygon
+    zone_demarcation = [zone_demarcation]
+    zone_demarcation_boundary_color = [zone_demarcation_boundary_color]
+    zone_demarcation_line_width = [zone_demarcation_line_width]
+    zone_demarcation_line_style = [zone_demarcation_line_style]
+
+    # Read background image
+    bg_img = Image.open(background_image_path)
+
+    # Normalize to 3d RGB
+    bg_img = bg_img.convert("RGB")
+
+    # Show the image on the plot
+    fig, ax = plt.subplots(figsize=(9.6, 7.2))
+    ax.imshow(bg_img)
+
+    # Add zone fill and boundary
+    for i in range(len(zone_demarcation)):
+        zone = LineString(zone_demarcation[i])
+        zone_x, zone_y = zone.xy
+        ax.plot(
+            zone_x,
+            zone_y,
+            color=zone_demarcation_boundary_color[i],
+            linewidth=zone_demarcation_line_width[i],
+            linestyle=zone_demarcation_line_style[i],
+            zorder=i + 1,
+            solid_capstyle="round",
+        )
+
+    # Remove axis
+    plt.axis("off")
+
+    # Save
+    plt.savefig(save_path, bbox_inches="tight", transparent=True, pad_inches=0)
+
+    return save_path
+
+
+    
+
+
 def overlay_zone_on_sample_image(
     background_image_path: str,
     zone_demarcation: Union[List[List[int]], List[List[List[int]]]],
@@ -332,7 +382,7 @@ def get_zone_heatmap(
             device_serial_no=device_serial_no,
             save_path=f"{tmp_dir}/sensor-bg-image.png",
         )
-        base_image = np.asarray(Image.open(sensor_sample_img_path))
+        base_image = np.array(Image.open(sensor_sample_img_path))
 
         # Convert datetimes
         if isinstance(start_datetime, datetime):
@@ -436,7 +486,7 @@ def get_feed_heatmap(
             device_serial_no=device_serial_no,
             save_path=f"{tmp_dir}/sensor-bg-image.png",
         )
-        base_image = np.asarray(Image.open(sensor_sample_img_path))
+        base_image = np.array(Image.open(sensor_sample_img_path))
 
         # Convert datetimes
         if isinstance(start_datetime, datetime):
@@ -476,6 +526,9 @@ def get_feed_heatmap(
         # Where the heatmap is greater than 0 in each sample (RGB / BGR) dimension
         # mult the alpha by the colormap value and merge with sensor sample image value
         alpha = 0.5
+        # Normalize base image to RGB
+        if len(base_image.shape) == 2:
+            base_image = cv2.cvtColor(base_image, cv2.COLOR_GRAY2BGR)
         for sample_dim_index in range(3):
             base_image[heatmap > 0, sample_dim_index] = (
                 alpha * colormap[heatmap > 0, sample_dim_index]
